==> qtjambi-nfc-6.3.5-sources.jar: io/qt/nfc/QNdefNfcIconRecord.java <==
package io.qt.nfc;


/**
 * <p>NFC MIME record to hold an icon</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qndefnfciconrecord.html">QNdefNfcIconRecord</a></p>
 */
public class QNdefNfcIconRecord extends io.qt.nfc.QNdefRecord
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfciconrecord.html#QNdefNfcIconRecord">QNdefNfcIconRecord::QNdefNfcIconRecord()</a></p>
     */
    public QNdefNfcIconRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefNfcIconRecord instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfciconrecord.html#QNdefNfcIconRecord-1">QNdefNfcIconRecord::QNdefNfcIconRecord(QNdefRecord)</a></p>
     */
    public QNdefNfcIconRecord(io.qt.nfc.QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcIconRecord instance, io.qt.nfc.QNdefRecord other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfciconrecord.html#data">QNdefNfcIconRecord::data()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QByteArray data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QByteArray data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfciconrecord.html#setData">QNdefNfcIconRecord::setData(QByteArray)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setData(io.qt.core.QByteArray data){
        setData_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data));
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QByteArray(long __this__nativeId, long data);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNdefNfcIconRecord(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QNdefNfcIconRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QNdefNfcIconRecord clone_native(long __this_nativeId);
}

==> qtjambi-nfc-6.5.1-sources.jar: io/qt/nfc/QNdefNfcIconRecord.java <==
package io.qt.nfc;

import io.qt.*;


/**
 * <p>NFC MIME record to hold an icon</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qndefnfciconrecord.html">QNdefNfcIconRecord</a></p>
 */
public class QNdefNfcIconRecord extends io.qt.nfc.QNdefRecord
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfciconrecord.html#QNdefNfcIconRecord">QNdefNfcIconRecord::QNdefNfcIconRecord()</a></p>
     */
    public QNdefNfcIconRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefNfcIconRecord instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfciconrecord.html#QNdefNfcIconRecord-1">QNdefNfcIconRecord::QNdefNfcIconRecord(QNdefRecord)</a></p>
     */
    public QNdefNfcIconRecord(io.qt.nfc.@NonNull QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcIconRecord instance, io.qt.nfc.QNdefRecord other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfciconrecord.html#data">QNdefNfcIconRecord::data()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QByteArray data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QByteArray data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfciconrecord.html#setData">QNdefNfcIconRecord::setData(QByteArray)</a></p>
     */
    @QtUninvokable
    public final void setData(io.qt.core.@NonNull QByteArray data){
        setData_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data));
    }
    
    @QtUninvokable
    private native void setData_native_cref_QByteArray(long __this__nativeId, long data);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QNdefNfcIconRecord(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QNdefNfcIconRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QNdefNfcIconRecord clone_native(long __this_nativeId);
}
